@@ -7,7 +7,7 @@ impl<'info> Validate<'info> for CreateGovernor<'info> {
     fn validate(&self) -> ProgramResult {
         invariant!(
             self.smart_wallet.owners.contains(&self.governor.key()),
-            SmartWalletNotFound
+            GovernorNotFound
         );
 
         Ok(())
@@ -22,12 +22,12 @@ impl<'info> Validate<'info> for CreateProposal<'info> {
 
 impl<'info> Validate<'info> for ActivateProposal<'info> {
     fn validate(&self) -> ProgramResult {
-        invariant!(
-            self.proposal.get_state(&self.governor)? == ProposalState::Draft,
-            "proposal must be draft to be activated"
-        );
         assert_keys_eq!(self.governor, self.proposal.governor);
         assert_keys_eq!(self.electorate, self.governor.electorate);
+        require!(
+            self.proposal.get_state(&self.governor)? == ProposalState::Draft,
+            ProposalNotDraft
+        );
 
         let earliest_activation_time = unwrap_int!(self
             .governor
@@ -50,10 +50,6 @@ impl<'info> Validate<'info> for ActivateProposal<'info> {
 
 impl<'info> Validate<'info> for CancelProposal<'info> {
     fn validate(&self) -> ProgramResult {
-        invariant!(
-            self.proposal.get_state(&self.governor)? == ProposalState::Draft,
-            "proposal must be draft to be canceled"
-        );
         assert_keys_eq!(
             self.proposer,
             self.proposal.proposer,
@@ -64,6 +60,10 @@ impl<'info> Validate<'info> for CancelProposal<'info> {
             self.proposal.governor,
             "proposal should be under the governor"
         );
+        require!(
+            self.proposal.get_state(&self.governor)? == ProposalState::Draft,
+            ProposalNotDraft
+        );
         Ok(())
     }
 }
@@ -121,10 +121,6 @@ impl<'info> Validate<'info> for NewVote<'info> {
 impl<'info> Validate<'info> for SetVote<'info> {
     fn validate(&self) -> ProgramResult {
         assert_keys_eq!(self.governor.electorate, self.electorate);
-        invariant!(
-            self.proposal.get_state(&self.governor)? == ProposalState::Active,
-            "proposal must be active to be voted on"
-        );
         assert_keys_eq!(
             self.governor,
             self.proposal.governor,
@@ -133,7 +129,11 @@ impl<'info> Validate<'info> for SetVote<'info> {
         assert_keys_eq!(
             self.vote.proposal,
             self.proposal,
-            "receipt proposal should match"
+            "vote proposal should match"
+        );
+        require!(
+            self.proposal.get_state(&self.governor)? == ProposalState::Active,
+            ProposalNotActive
         );
         Ok(())
     }
